import 'dart:io';

import 'package:apk_update/core/common/version_info.dart';
import 'package:apk_update/core/services/version_service/version_service.dart';

import '../../../../utils/dio_update_util.dart';
import '../../../../utils/toast_util.dart';
import '../../../common/app_upgrade_config.dart';
import '../../../common/servier_api.dart';

/// 项目管理工具
class PMVersionImpl implements VersionService {
  final AppUpgradeConfig config;

  const PMVersionImpl({required this.config});

  @override
  Future<VersionInfo?> checkVersion() async {
    // ①版本检测
    var checkResult = await checkVersionPM();
    // ②获取版本详情
    var result = await getVersionDetailPM(checkResult?['id']);
    // 返回升级版本信息
    return VersionInfo(
      name: result['name'],
      content: result['popContent'],
      versionForce: result['forceUpgradeStatus'] == 1,
      versionPath: result['versionPath'],
    );
  }

  /// 版本检测
  Future<dynamic> checkVersionPM() async {
    var checkResult = await DioUpdateUtil.get(
      "${config.baseUrl}${ServerApi.getLatestByProductCodePM}",
      queryParameters: {
        "productCode": config.productCode,
        "currentVersion": config.versionNumber,
        "sideType": Platform.isIOS ? 2 : 1
      },
      headers: {"productGroupCode": "common"},
    );
    if (checkResult == null) return null;
    // 是否是最新版本提示
    final newVersion =
        int.tryParse(checkResult?['version']?.toString() ?? '') ?? 0;
    final currentVersion =
        int.tryParse(config.versionNumber?.toString() ?? '') ?? 0;
    if (newVersion <= currentVersion) {
      if (!config.onceDay) {
        ToastUtil.showToast('已经是最新版本了！');
      }
      return null;
    }
    return checkResult;
  }

  /// 获取版本详情
  Future<dynamic> getVersionDetailPM(int? id) async {
    var detailResult = await DioUpdateUtil.get(
        "${config.baseUrl}${ServerApi.getDetailPM}",
        queryParameters: {'id': id},
        headers: {"productGroupCode": "common"});
    if (detailResult == null) return null;
    // 是否是最新版本提示
    final newVersion =
        int.tryParse(detailResult?['version']?.toString() ?? '') ?? 0;
    final currentVersion =
        int.tryParse(config.versionNumber?.toString() ?? '') ?? 0;
    if (newVersion <= currentVersion) {
      if (!config.onceDay) {
        ToastUtil.showToast('已经是最新版本了！');
      }
      return null;
    }
    return detailResult;
  }
}
